@@ -12,11 +12,11 @@
 
 #include <math.h>
 
-#include <QtCore/QList>
-#include <QtGui/QColor>
-#include <QtGui/QPainterPath>
-#include <QtGui/QTransform>
-#include <QtCore/QDebug>
+#include <QList>
+#include <QColor>
+#include <QPainterPath>
+#include <QTransform>
+#include <QDebug>
 
 #include "global.h"
 #include "okularcore_export.h"
@@ -448,7 +448,7 @@ class OKULARCORE_EXPORT AnnotationObjectRect : public ObjectRect
          * Creates a new annotation object rectangle with the
          * given @p annotation.
          */
-        AnnotationObjectRect( Annotation *annotation );
+        explicit AnnotationObjectRect( Annotation *annotation );
 
         /**
          * Destroys the annotation object rectangle.
@@ -669,7 +669,7 @@ template <class NormalizedShape, class Shape>
 bool RegularArea<NormalizedShape, Shape>::isNull() const
 {
     if ( this->isEmpty() )
-        return false;
+        return true;
 
     typename QList<NormalizedShape>::const_iterator it = this->begin(), itEnd = this->end();
     for ( ; it != itEnd; ++it )
@@ -871,7 +871,7 @@ class HighlightAreaRect : public RegularAreaRect
          * Creates a new highlight area rect with the coordinates of
          * the given @p area.
          */
-        HighlightAreaRect( const RegularAreaRect *area = nullptr );
+        explicit HighlightAreaRect( const RegularAreaRect *area = nullptr );
 
         /**
          * The search ID of the highlight owner.
