@@ -14,18 +14,18 @@
 #ifndef FILEPRINTER_H
 #define FILEPRINTER_H
 
-#include <QtCore/QList>
-#include <QtCore/QString>
-#include <QtGui/QPrinter>
+#include <QList>
+#include <QString>
+#include <QPrinter>
 
-#include "okular_export.h"
+#include "okularcore_export.h"
 #include "generator.h"
 
 class QSize;
 
 namespace Okular {
 
-class OKULAR_EXPORT FilePrinter
+class OKULARCORE_EXPORT FilePrinter
 {
 public:
 
@@ -60,7 +60,7 @@ public:
      * @param documentOrientation the orientation stored in the document itself
      * @param fileDeletePolicy if the application or system deletes the file
      * @param pageSelectPolicy if the application or system selects the pages to print
-     * @param pageRange page range to print if SystemSlectsPages and user chooses Selection in Print Dialog
+     * @param pageRange page range to print if SystemSelectsPages and user chooses Selection in Print Dialog
      *
      * @returns Returns exit code:
      *          -9 if lpr not found
