@@ -15,7 +15,7 @@
 #include <kjs/kjsprototype.h>
 #include <kjs/kjsarguments.h>
 
-#include <QtCore/QDebug>
+#include <QDebug>
 
 #include "../debug_p.h"
 #include "../document_p.h"
