@@ -12,7 +12,7 @@
 #include "debug_dvi.h"
 #include "debug_dvi.h"
 
-#include <QtCore/qloggingcategory.h>
+#include <QLoggingCategory>
 #include <QDataStream>
 #include <QFile>
 
