@@ -22,7 +22,7 @@
 #include <QExplicitlySharedDataPointer>
 
 #include <QObject>
-#include <QtPrintSupport/QPrinter>
+#include <QPrinter>
 
 
 class dviRenderer;
@@ -118,6 +118,7 @@ public:
    *  passed to the external process's argv command line.
    *  @param printer having generated the PostScript file, it is passed
    *  to @c printer (if not null).
+   *  @param useFontHinting boolean that defines whether to use font hinting.
    *  @param orientation the original orientation of the document
    */
   DVIExportToPS(dviRenderer& parent,
@@ -128,8 +129,8 @@ public:
                 QPrinter::Orientation orientation = QPrinter::Portrait);
 
 private:
-  virtual void abort_process_impl();
-  virtual void finished_impl(int exit_code);
+  void abort_process_impl() override;
+  void finished_impl(int exit_code) override;
 
   QPrinter* printer_;
   QString output_name_;
