@@ -80,7 +80,7 @@ class ThumbnailsBox : public QWidget
     Q_OBJECT
 
     public:
-        ThumbnailsBox( QWidget * parent ) : QWidget( parent ) { QVBoxLayout *vbox = new QVBoxLayout(this); vbox->setMargin(0); vbox->setSpacing(0);}
+        explicit ThumbnailsBox( QWidget * parent ) : QWidget( parent ) { QVBoxLayout *vbox = new QVBoxLayout(this); vbox->setMargin(0); vbox->setSpacing(0);}
         QSize sizeHint() const override { return QSize(); }
 };
 
